<?php
// FORÇA O PHP E O NAVEGADOR A USAREM UTF-8
header('Content-Type: text/html; charset=utf-8');
session_start();
require_once 'config.php'; 

$pdo = getConexaoAtiva(); // Banco Principal
$pdo_int = getConexaoInterna(); // Banco Local

// FORÇA A CONEXÃO COM O BANCO A USAR UTF-8 ANTES DE QUALQUER BUSCA
$pdo->exec("SET NAMES utf8mb4");
$pdo_int->exec("SET NAMES utf8mb4");
$pdo->exec("SET CHARACTER SET utf8mb4");
$pdo_int->exec("SET CHARACTER SET utf8mb4");

// ====================================================================
// INTELIGÊNCIA ARTIFICIAL: DETECTA SE É XUI ONE OU XTREAM UI
// ====================================================================
$modo_ativo = 'interno';
try {
    $modo_ativo = $pdo_int->query("SELECT modo_ativo FROM configuracoes LIMIT 1")->fetchColumn() ?: 'interno';
} catch (Exception $e) {}

// --- INÍCIO: BUSCA DE PERSONALIZAÇÃO DINÂMICA ---
$nome_painel = 'TOP IPTV';
$logo_url = '';
$cor_primaria = '#007bff';

try {
    // Busca no Banco Interno
    $tabela_existe = $pdo_int->query("SHOW TABLES LIKE 'painel_config'")->rowCount() > 0;
    if ($tabela_existe) {
        $config_painel = $pdo_int->query("SELECT * FROM painel_config LIMIT 1")->fetch(PDO::FETCH_ASSOC);
        if ($config_painel) {
            $nome_painel = !empty($config_painel['nome_painel']) ? $config_painel['nome_painel'] : $nome_painel;
            $logo_url = !empty($config_painel['logo_url']) ? $config_painel['logo_url'] : $logo_url;
            $cor_primaria = !empty($config_painel['cor_primaria']) ? $config_painel['cor_primaria'] : $cor_primaria;
        }
    }
} catch (Exception $e) {}
// --- FIM: BUSCA DE PERSONALIZAÇÃO DINÂMICA ---

if (!isset($_SESSION['user_id'])) { header("Location: login.php"); exit; }

$role = $_SESSION['user_role'] ?? 'reseller'; 
$nome_usuario = $_SESSION['username'] ?? 'Usuário';
$user_id_logado = $_SESSION['user_id'];

try {
    // Busca créditos no Banco Interno
    $user_credits = $pdo_int->query("SELECT credits FROM reg_users WHERE id = " . intval($user_id_logado))->fetchColumn() ?: 0;
} catch (Exception $e) { $user_credits = 0; }

// =========================================================================
// 1. AUTO-CRIAÇÃO DA TABELA DE CONFIGURAÇÕES DE PAGAMENTO (NO BANCO INTERNO)
// =========================================================================
try {
    $pdo_int->exec("CREATE TABLE IF NOT EXISTS revendedor_configuracoes (
        id INT AUTO_INCREMENT PRIMARY KEY,
        revendedor_id INT NOT NULL UNIQUE,
        mp_access_token VARCHAR(255) DEFAULT '',
        asaas_api_key VARCHAR(255) DEFAULT '',
        webhook_token VARCHAR(100) DEFAULT ''
    )");
} catch (Exception $e) {}

$feedback = '';

// =========================================================================
// 2. SALVAR CONFIGURAÇÕES (NO BANCO INTERNO)
// =========================================================================
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['salvar_config'])) {
    $mp_access = trim($_POST['mp_access_token'] ?? '');
    $asaas_key = trim($_POST['asaas_api_key'] ?? '');
    
    $stmt = $pdo_int->prepare("UPDATE revendedor_configuracoes SET mp_access_token = ?, asaas_api_key = ? WHERE revendedor_id = ?");
    $stmt->execute([$mp_access, $asaas_key, $user_id_logado]);
    
    $feedback = '<div class="alert success"><i class="fas fa-check-circle"></i> Configurações salvas com sucesso!</div>';
}

// =========================================================================
// 3. BUSCAR OU GERAR DADOS ATUAIS (URL ÚNICA DO WEBHOOK) (NO BANCO INTERNO)
// =========================================================================
$stmt_get = $pdo_int->prepare("SELECT * FROM revendedor_configuracoes WHERE revendedor_id = ?");
$stmt_get->execute([$user_id_logado]);
$config = $stmt_get->fetch(PDO::FETCH_ASSOC);

if (!$config) {
    $novo_token = md5($user_id_logado . time() . 'iptv');
    $pdo_int->prepare("INSERT INTO revendedor_configuracoes (revendedor_id, webhook_token) VALUES (?, ?)")->execute([$user_id_logado, $novo_token]);
    $config = ['mp_access_token' => '', 'asaas_api_key' => '', 'webhook_token' => $novo_token];
} elseif (empty($config['webhook_token'])) {
    $novo_token = md5($user_id_logado . time() . 'iptv');
    $pdo_int->prepare("UPDATE revendedor_configuracoes SET webhook_token = ? WHERE revendedor_id = ?")->execute([$novo_token, $user_id_logado]);
    $config['webhook_token'] = $novo_token;
}

// --- LINK CORRIGIDO APONTANDO PARA A PASTA API E O ARQUIVO CORRETO ---
$protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') ? "https://" : "http://";
$webhook_url = $protocol . $_SERVER['HTTP_HOST'] . "/api/webhook_pagamentos.php?token=" . $config['webhook_token'];

?>
<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <link rel="stylesheet" href="tema.css">
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
    <title>Pagamentos - <?php echo htmlspecialchars($nome_painel); ?></title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        :root { --bg-dark: #121519; --bg-sidebar: #1e2227; --bg-card: #272c33; --text-main: #d1d5da; --text-muted: #8a94a1; --accent: <?php echo $cor_primaria; ?>; --border-color: #3a4149; --success: #28a745; --danger: #dc3545; }
        body { margin: 0; font-family: 'Segoe UI', sans-serif; background-color: var(--bg-dark); color: var(--text-main); display: flex; height: 100vh; overflow: hidden; }
        
        /* CSS OBRIGATÓRIO PARA A LOGO E MENU (Evita o bug da logo gigante) */
        .sidebar { width: 260px; background-color: var(--bg-sidebar); display: flex; flex-direction: column; transition: 0.3s; border-right: 1px solid var(--border-color); z-index: 1001; flex-shrink: 0; }
        .sidebar-header { padding: 25px 20px; text-align: center; font-size: 22px; font-weight: bold; color: white; border-bottom: 1px solid var(--border-color); }
        .sidebar-logo { max-width: 180px; max-height: 55px; object-fit: contain; }
        .user-info { padding: 20px; text-align: center; border-bottom: 1px solid var(--border-color); }
        .user-info .badge { background: rgba(255, 255, 255, 0.05); color: var(--accent); padding: 4px 10px; border-radius: 4px; font-size: 11px; text-transform: uppercase; font-weight: bold; margin-top: 5px; display: inline-block; }
        .credits-badge { display: block; margin-top: 10px; color: var(--success); font-weight: bold; font-size: 13px; }
        
        .menu-list { list-style: none; padding: 0; margin: 0; overflow-y: auto; flex: 1; }
        .menu-item { padding: 14px 20px; color: var(--text-main); text-decoration: none; display: flex; align-items: center; transition: 0.2s; border-left: 3px solid transparent; font-size: 14px; cursor: pointer; }
        .menu-item i:first-child { margin-right: 12px; width: 20px; text-align: center; color: var(--text-muted); }
        .menu-item:hover, .menu-item.active { background-color: #2c3138; color: white; border-left-color: var(--accent); }
        .menu-item.active i:first-child { color: var(--accent); }
        
        .submenu { display: none; background: #16191d; list-style: none; padding: 0; margin: 0; }
        .submenu .menu-item { padding-left: 52px; font-size: 13px; border-left: none; }
        .arrow-icon { margin-left: auto; transition: 0.3s; font-size: 11px; }
        .rotate { transform: rotate(180deg); }
        .menu-category { padding: 20px 20px 8px; font-size: 10px; text-transform: uppercase; color: var(--text-muted); font-weight: bold; letter-spacing: 1px; }
        .logout-btn { padding: 15px; background-color: var(--danger); color: white; text-align: center; text-decoration: none; font-weight: bold; }

        .main-content { flex: 1; display: flex; flex-direction: column; overflow-y: auto; width: 100%; position: relative; }
        .topbar { display: flex; justify-content: space-between; align-items: center; padding: 15px 30px; background-color: var(--bg-sidebar); border-bottom: 1px solid var(--border-color); }
        .menu-toggle { display: none; background: none; border: none; color: white; font-size: 22px; cursor: pointer; padding: 5px; }
        .mode-badge { padding: 6px 15px; background: rgba(40, 167, 69, 0.15); color: var(--success); border-radius: 20px; font-size: 12px; font-weight: bold; border: 1px solid var(--success); white-space: nowrap; }
        .content-area { padding: 30px; flex: 1; }
        
        .page-header { margin-bottom: 25px; }
        .page-header h3 { font-size: 24px; color: white; margin: 0 0 5px 0; display: flex; align-items: center; gap: 10px; }
        .page-header p { color: var(--text-muted); margin: 0; }

        .alert { padding: 15px; border-radius: 8px; margin-bottom: 20px; font-size: 14px; }
        .alert.success { background: rgba(40, 167, 69, 0.1); color: var(--success); border: 1px solid var(--success); }

        .custom-card { background-color: var(--bg-card); border: 1px solid var(--border-color); border-radius: 10px; overflow: hidden; margin-bottom: 30px; }
        .custom-card-header { background-color: #1e2227; color: white; padding: 15px 20px; font-size: 16px; font-weight: bold; border-bottom: 1px solid var(--border-color); }
        .custom-card-body { padding: 25px; }

        .form-group { margin-bottom: 20px; }
        .form-group label { display: block; margin-bottom: 8px; font-weight: 600; color: white; font-size: 14px; }
        .form-control { width: 100%; padding: 12px; background: #121519; border: 1px solid var(--border-color); color: white; border-radius: 6px; box-sizing: border-box; font-family: inherit; transition: 0.3s; }
        .form-control:focus { border-color: var(--accent); outline: none; }
        .form-text { font-size: 12px; color: var(--text-muted); margin-top: 5px; }

        .btn { padding: 12px 25px; border-radius: 6px; font-weight: bold; cursor: pointer; border: none; color: white; display: inline-flex; align-items: center; justify-content: center; gap: 8px; font-size: 14px; text-decoration: none; transition: 0.2s; }
        .btn-primary { background: var(--accent); width: 100%; }
        .btn-primary:hover { filter: brightness(1.1); }

        .webhook-box { background: rgba(40,167,69,0.1); border: 1px dashed var(--success); padding: 20px; border-radius: 8px; margin-top: 10px; }
        .webhook-box h5 { margin: 0 0 10px 0; color: var(--success); font-size: 16px; }
        .input-group { display: flex; width: 100%; }
        .input-group input { flex: 1; border-radius: 6px 0 0 6px; background: #121519; border-color: var(--success); color: white; padding: 12px; }
        .input-group button { border-radius: 0 6px 6px 0; background: var(--success); border: none; color: white; padding: 0 20px; font-weight: bold; cursor: pointer; transition: 0.2s; }
        .input-group button:hover { filter: brightness(1.2); }

        .sidebar-overlay { display: none; position: fixed; top: 0; left: 0; width: 100%; height: 100%; background: rgba(0,0,0,0.7); z-index: 1000; }

        @media (max-width: 768px) {
            .sidebar { position: fixed; left: -260px; height: 100%; box-shadow: 10px 0 20px rgba(0,0,0,0.5); }
            .sidebar.active { left: 0; }
            .menu-toggle { display: block; margin-right: 15px;}
            .sidebar-overlay.active { display: block; }
            .topbar { padding: 15px 20px; justify-content: flex-start; gap: 10px; }
            .topbar-right { display: flex; align-items: center; margin-left: auto; }
            .content-area { padding: 15px; padding-bottom: 120px;}
        }
    </style>
</head>
<body>
    <div class="sidebar-overlay" id="overlay" onclick="toggleMenu()"></div>

    <?php include 'sidebar.php'; ?>

    <div class="main-content">
        <header class="topbar">
            <div style="display:flex; align-items:center;">
                <button class="menu-toggle" onclick="toggleMenu()"><i class="fas fa-bars"></i></button>
                <h2 style="margin:0; font-size: 18px; color:white;">Módulo de Pagamentos</h2>
            </div>
            <div class="topbar-right">
                <span class="mode-badge"><i class="fas fa-database"></i> MODO: <?php echo defined('MODO_SISTEMA') ? strtoupper(MODO_SISTEMA) : strtoupper($modo_ativo); ?></span>
            </div>
        </header>

        <div class="content-area">
            <div class="page-header">
                <h3><i class="fas fa-dollar-sign"></i> Renovação Automática</h3>
                <p>Configure o Mercado Pago ou Asaas para renovar seus clientes automaticamente 24h por dia.</p>
            </div>

            <?php echo $feedback; ?>

            <div class="custom-card" style="border-color: var(--success);">
                <div class="custom-card-header" style="background-color: rgba(40,167,69,0.1); color: var(--success);">
                    <i class="fas fa-link"></i> Sua URL de Integração (Webhook)
                </div>
                <div class="custom-card-body">
                    <p style="margin-top:0;">Copie esta URL Exclusiva e cole no painel do <strong>Mercado Pago</strong> (Notificações) ou <strong>Asaas</strong> (Webhooks). O sistema saberá que é você!</p>
                    <div class="input-group">
                        <input type="text" class="form-control" value="<?php echo htmlspecialchars($webhook_url); ?>" id="webhook-url" readonly>
                        <button type="button" onclick="copiarWebhook()"><i class="fas fa-copy"></i> Copiar URL</button>
                    </div>
                </div>
            </div>

            <div class="custom-card">
                <div class="custom-card-header">Suas Chaves de Acesso (API)</div>
                <div class="custom-card-body">
                    <form method="POST">
                        <input type="hidden" name="salvar_config" value="1">
                        
                        <div class="form-group">
                            <label><i class="fas fa-handshake" style="color:#009ee3;"></i> Mercado Pago - Access Token (Produção)</label>
                            <input type="text" name="mp_access_token" class="form-control" value="<?php echo htmlspecialchars($config['mp_access_token'] ?? ''); ?>" placeholder="APP_USR-...">
                            <div class="form-text">Seu token oficial de produção gerado no painel do desenvolvedor do Mercado Pago.</div>
                        </div>

                        <hr style="border-color: var(--border-color); margin: 25px 0;">

                        <div class="form-group">
                            <label><i class="fas fa-building" style="color:#28a745;"></i> Asaas - API Key</label>
                            <input type="text" name="asaas_api_key" class="form-control" value="<?php echo htmlspecialchars($config['asaas_api_key'] ?? ''); ?>" placeholder="$aact_...">
                            <div class="form-text">Sua chave de integração gerada nas configurações da sua conta Asaas.</div>
                        </div>
                        
                        <button type="submit" class="btn btn-primary"><i class="fas fa-save"></i> Salvar Integração</button>
                    </form>
                </div>
            </div>

            <div class="custom-card">
                <div class="custom-card-header"><i class="fas fa-info-circle"></i> Como funciona a renovação?</div>
                <div class="custom-card-body" style="font-size: 14px; line-height: 1.6; color: var(--text-muted);">
                    <strong>Regra de Ouro:</strong> Para que o painel saiba qual cliente renovar, você precisa colocar o <strong>nome de usuário do cliente</strong> na hora de gerar a cobrança.<br><br>
                    <ul style="padding-left:20px;">
                        <li><strong>No Mercado Pago:</strong> Ao gerar o link de cobrança ou botão, preencha o campo <code>external_reference</code> (Referência Externa) com o usuário do cliente.</li>
                        <li><strong>No Asaas:</strong> Ao criar a cobrança no seu painel Asaas, coloque o usuário do cliente no campo <strong>"Identificador Externo"</strong>.</li>
                    </ul>
                    Assim que a fatura for paga pelo cliente (Pix, Boleto ou Cartão), o banco avisa seu painel por aquela URL lá de cima. O painel localiza o cliente, adiciona <strong>+30 dias</strong> na validade dele e, se você for revendedor, debita 1 crédito do seu saldo automaticamente!
                </div>
            </div>

        </div>
        <?php include 'rodape.php'; ?>
    </div>

    <script>
        function toggleMenu() { 
            document.getElementById('sidebar').classList.toggle('active'); 
            document.getElementById('overlay').classList.toggle('active'); 
        }

        function toggleSubmenu(id) {
            const sub = document.getElementById(id);
            const arrow = document.getElementById('arrow-' + id);
            if (sub.style.display === "block") { 
                sub.style.display = "none"; 
                if(arrow) arrow.classList.remove('rotate'); 
            } 
            else { 
                sub.style.display = "block"; 
                if(arrow) arrow.classList.add('rotate'); 
            }
        }

        function copiarWebhook() {
            var copyText = document.getElementById("webhook-url");
            copyText.select();
            copyText.setSelectionRange(0, 99999);
            document.execCommand("copy");
            
            const btn = document.querySelector('.input-group button');
            const txtOriginal = btn.innerHTML;
            btn.innerHTML = '<i class="fas fa-check"></i> Copiado!';
            setTimeout(() => { btn.innerHTML = txtOriginal; }, 2000);
        }
    </script>
    <script src="tema.js"></script>
</body>
</html>
