<?php
// play.php
ob_start();
$token = $_GET['token'] ?? '';
$id = $_GET['id'] ?? '';

if (strpos($token, 'NBR_') === 0) {
    $base64 = substr($token, 4);
    $decoded = base64_decode(strtr($base64, '-_', '+/'));
    
    if ($decoded && strpos($decoded, ':') !== false) {
        list($user, $pass) = explode(':', $decoded);
        
        $url_completa = $_SERVER['REQUEST_URI'];
        $ext = 'ts'; 
        if (preg_match('/\.([a-zA-Z0-9]{2,4})$/', $url_completa, $matches)) {
            $ext = strtolower($matches[1]);
        }

        // Melhora a detecção do protocolo (útil para Cloudflare/SSL)
        $protocol = "http";
        if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on') $protocol = "https";
        if (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] === 'https') $protocol = "https";
        
        $host = $_SERVER['HTTP_HOST'];
        
        // Em vez de redirecionar para /live/ que vai ser reescrito de novo, 
        // redirecionamos para o link que o stream.php entende.
        if (in_array($ext, ['mp4', 'mkv', 'avi'])) {
            $link_real = "{$protocol}://{$host}/movie/{$user}/{$pass}/{$id}.{$ext}";
        } else {
            $ext_final = ($ext === 'm3u8') ? 'm3u8' : 'ts';
            $link_real = "{$protocol}://{$host}/live/{$user}/{$pass}/{$id}.{$ext_final}";
        }
        
        ob_clean();
        header("Location: " . $link_real);
        exit;
    }
}

header("HTTP/1.0 403 Forbidden");
exit;